@@ -1,15 +1,15 @@
 /** ===========================================================
  * @file
  *
- * This file is a part of kipi-plugins project
- * <a href="http://www.digikam.org">http://www.digikam.org</a>
+ * This file is a part of KDE project
+ *
  *
  * @date   2012-06-28
  * @brief  kipi host test application using KDE XML-GUI technology
  *
  * @author Copyright (C) 2012 by Victor Dodon
  *         <a href="mailto:dodonvictor at gmail dot com">dodonvictor at gmail dot com</a>
- * @author Copyright (C) 2012-2017 by Gilles Caulier
+ * @author Copyright (C) 2012-2018 by Gilles Caulier
  *         <a href="mailto:caulier dot gilles at gmail dot com">caulier dot gilles at gmail dot com</a>
  *
  * This program is free software; you can redistribute it
@@ -43,11 +43,11 @@
 #include <QStandardPaths>
 #include <QDialogButtonBox>
 
-// KDE includes
+// KF includes
 
-#include <ksharedconfig.h>
-#include <kconfiggroup.h>
-#include <kwindowconfig.h>
+#include <KSharedConfig>
+#include <KConfigGroup>
+#include <KWindowConfig>
 
 // Libkipi includes
 
@@ -71,11 +71,11 @@ class KipiSetup::Private
 public:
 
     Private() :
-        pluginFilter(0),
-        buttons(0),
-        tabView(0),
-        pluginsList(0),
-        xmlPage(0)
+        pluginFilter(nullptr),
+        buttons(nullptr),
+        tabView(nullptr),
+        pluginsList(nullptr),
+        xmlPage(nullptr)
     {
     }
 
@@ -200,7 +200,7 @@ public:
 
     Private()
     {
-        xmlFilesCob = 0;
+        xmlFilesCob = nullptr;
     }
 
     QString        uiFilesPath;
